@@ -300,7 +300,7 @@ class MessageMeta(type):
         """
         # Optimized fast path.
         instance = cls.__new__(cls)
-        instance.__dict__["_pb"] = pb
+        super(cls, instance).__setattr__("_pb", pb)
         return instance
 
     def serialize(cls, instance) -> bytes:
@@ -369,7 +369,9 @@ class MessageMeta(type):
         Parse(payload, instance._pb, ignore_unknown_fields=ignore_unknown_fields)
         return instance
 
-    def to_dict(cls, instance, *, use_integers_for_enums=True) -> "Message":
+    def to_dict(
+        cls, instance, *, use_integers_for_enums=True, preserving_proto_field_name=True
+    ) -> "Message":
         """Given a message instance, return its representation as a python dict.
 
         Args:
@@ -378,6 +380,9 @@ class MessageMeta(type):
             use_integers_for_enums (Optional(bool)): An option that determines whether enum
                 values should be represented by strings (False) or integers (True).
                 Default is True.
+            preserving_proto_field_name (Optional(bool)): An option that
+                determines whether field name representations preserve
+                proto case (snake_case) or use lowerCamelCase. Default is True.
 
         Returns:
             dict: A representation of the protocol buffer using pythonic data structures.
@@ -387,7 +392,7 @@ class MessageMeta(type):
         return MessageToDict(
             cls.pb(instance),
             including_default_value_fields=True,
-            preserving_proto_field_name=True,
+            preserving_proto_field_name=preserving_proto_field_name,
             use_integers_for_enums=use_integers_for_enums,
         )
 
@@ -414,7 +419,7 @@ class Message(metaclass=MessageMeta):
         if mapping is None:
             if not kwargs:
                 # Special fast path for empty construction.
-                self.__dict__["_pb"] = self._meta.pb()
+                super().__setattr__("_pb", self._meta.pb())
                 return
 
             mapping = kwargs
@@ -430,7 +435,7 @@ class Message(metaclass=MessageMeta):
             if kwargs:
                 mapping.MergeFrom(self._meta.pb(**kwargs))
 
-            self.__dict__["_pb"] = mapping
+            super().__setattr__("_pb", mapping)
             return
         elif isinstance(mapping, type(self)):
             # Just use the above logic on mapping's underlying pb.
@@ -468,7 +473,7 @@ class Message(metaclass=MessageMeta):
                 params[key] = pb_value
 
         # Create the internal protocol buffer.
-        self.__dict__["_pb"] = self._meta.pb(**params)
+        super().__setattr__("_pb", self._meta.pb(**params))
 
     def __bool__(self):
         """Return True if any field is truthy, False otherwise."""
